==> glib2-2.20.5-x86_64-1gsb.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libglib-2.0.so )
( cd usr/lib64 ; ln -sf libglib-2.0.so.0.2000.5 libglib-2.0.so )
( cd usr/lib64 ; rm -rf libgio-2.0.so )
( cd usr/lib64 ; ln -sf libgio-2.0.so.0.2000.5 libgio-2.0.so )
( cd usr/lib64 ; rm -rf libgmodule-2.0.so.0 )
( cd usr/lib64 ; ln -sf libgmodule-2.0.so.0.2000.5 libgmodule-2.0.so.0 )
( cd usr/lib64 ; rm -rf libgobject-2.0.so.0 )
( cd usr/lib64 ; ln -sf libgobject-2.0.so.0.2000.5 libgobject-2.0.so.0 )
( cd usr/lib64 ; rm -rf libgmodule-2.0.so )
( cd usr/lib64 ; ln -sf libgmodule-2.0.so.0.2000.5 libgmodule-2.0.so )
( cd usr/lib64 ; rm -rf libglib-2.0.so.0 )
( cd usr/lib64 ; ln -sf libglib-2.0.so.0.2000.5 libglib-2.0.so.0 )
( cd usr/lib64 ; rm -rf libgthread-2.0.so.0 )
( cd usr/lib64 ; ln -sf libgthread-2.0.so.0.2000.5 libgthread-2.0.so.0 )
( cd usr/lib64 ; rm -rf libgthread-2.0.so )
( cd usr/lib64 ; ln -sf libgthread-2.0.so.0.2000.5 libgthread-2.0.so )
( cd usr/lib64 ; rm -rf libgobject-2.0.so )
( cd usr/lib64 ; ln -sf libgobject-2.0.so.0.2000.5 libgobject-2.0.so )
( cd usr/lib64 ; rm -rf libgio-2.0.so.0 )
( cd usr/lib64 ; ln -sf libgio-2.0.so.0.2000.5 libgio-2.0.so.0 )

# Handle the incoming configuration files:
config() {
  for infile in $1; do
    NEW="$infile"
    OLD="`dirname $NEW`/`basename $NEW .new`"
    # If there's no config file by that name, mv it over:
    if [ ! -r $OLD ]; then 
     if [ -f $NEW ]; then
      mv $NEW $OLD
     fi;
    elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then
      # toss the redundant copy
      rm -f $NEW
    fi
    # Otherwise, we leave the .new copy for the admin to consider...
  done
}

# Prepare the new configuration files
for file in etc/profile.d/libglib2.csh.new etc/profile.d/libglib2.sh.new ; do
  if test -e $(dirname $file)/$(basename $file .new) ; then
    if [ ! -x $(dirname $file)/$(basename $file .new) ]; then
      chmod 644 $file
     else
      chmod 755 $file
    fi
  fi
  config $file
done

==> glib2-2.24.1-x86_64-1gsb.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libgthread-2.0.so )
( cd usr/lib64 ; ln -sf libgthread-2.0.so.0.2400.1 libgthread-2.0.so )
( cd usr/lib64 ; rm -rf libglib-2.0.so )
( cd usr/lib64 ; ln -sf libglib-2.0.so.0.2400.1 libglib-2.0.so )
( cd usr/lib64 ; rm -rf libgmodule-2.0.so )
( cd usr/lib64 ; ln -sf libgmodule-2.0.so.0.2400.1 libgmodule-2.0.so )
( cd usr/lib64 ; rm -rf libgio-2.0.so.0 )
( cd usr/lib64 ; ln -sf libgio-2.0.so.0.2400.1 libgio-2.0.so.0 )
( cd usr/lib64 ; rm -rf libglib-2.0.so.0 )
( cd usr/lib64 ; ln -sf libglib-2.0.so.0.2400.1 libglib-2.0.so.0 )
( cd usr/lib64 ; rm -rf libgobject-2.0.so )
( cd usr/lib64 ; ln -sf libgobject-2.0.so.0.2400.1 libgobject-2.0.so )
( cd usr/lib64 ; rm -rf libgthread-2.0.so.0 )
( cd usr/lib64 ; ln -sf libgthread-2.0.so.0.2400.1 libgthread-2.0.so.0 )
( cd usr/lib64 ; rm -rf libgmodule-2.0.so.0 )
( cd usr/lib64 ; ln -sf libgmodule-2.0.so.0.2400.1 libgmodule-2.0.so.0 )
( cd usr/lib64 ; rm -rf libgobject-2.0.so.0 )
( cd usr/lib64 ; ln -sf libgobject-2.0.so.0.2400.1 libgobject-2.0.so.0 )
( cd usr/lib64 ; rm -rf libgio-2.0.so )
( cd usr/lib64 ; ln -sf libgio-2.0.so.0.2400.1 libgio-2.0.so )

# Handle the incoming configuration files:
config() {
  for infile in $1; do
    NEW="$infile"
    OLD="`dirname $NEW`/`basename $NEW .new`"
    # If there's no config file by that name, mv it over:
    if [ ! -r $OLD ]; then 
     if [ -f $NEW ]; then
      mv $NEW $OLD
     fi;
    elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then
      # toss the redundant copy
      rm -f $NEW
    fi
    # Otherwise, we leave the .new copy for the admin to consider...
  done
}

# Prepare the new configuration files
for file in etc/profile.d/libglib2.csh.new etc/profile.d/libglib2.sh.new ; do
  if test -e $(dirname $file)/$(basename $file .new) ; then
    if [ ! -x $(dirname $file)/$(basename $file .new) ]; then
      chmod 644 $file
     else
      chmod 755 $file
    fi
  fi
  config $file
done
